@@ -688,7 +688,6 @@ instance Store a => Store (Product a)
 instance Store a => Store (First a)
 instance Store a => Store (Last a)
 instance Store a => Store (Maybe a)
-instance (Store a, Store b) => Store (Either a b)
 
 -- FIXME: have TH deriving handle unboxed fields?
 
@@ -702,6 +701,7 @@ $($(derive [d|
     instance Deriving (Store Any)
     instance Deriving (Store Void)
     instance Deriving (Store Bool)
+    instance (Store a, Store b) => Deriving (Store (Either a b))
     |]))
 
 -- TODO: higher arities?  Limited now by Generics instances for tuples
